==> ejc-metadata-api-3.0.0-20210617.120258-157-sources.jar: com/ejianc/foundation/metadata/vo/MdQuoteVO.java <==
package com.ejianc.foundation.metadata.vo;

/**
 * 查询引用关系返回VO
 */
public class MdQuoteVO {

	private static final long serialVersionUID = 1L;

	private String projectName;		//工程名称
	
	private String projectDisplayName;		//工程名称
	
	private Long projectId;			//工程id
	
	private String databaseName; //工程对应数据库名称

	private String entityName; // 实体名称

	private String entityDisplayName; // 实体名称

	private String entityFullName; // 实体全名

	private String tableName; // 表名称
	
	private Long attributeId;	//引用字段id
	
	private String attributeName;	//引用字段名称

	private String attributeCode;	//引用字段(数据库表中的名称)

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getDatabaseName() {
		return databaseName;
	}

	public void setDatabaseName(String databaseName) {
		this.databaseName = databaseName;
	}

	public String getEntityName() {
		return entityName;
	}

	public void setEntityName(String entityName) {
		this.entityName = entityName;
	}

	public String getEntityFullName() {
		return entityFullName;
	}

	public void setEntityFullName(String entityFullName) {
		this.entityFullName = entityFullName;
	}

	public String getTableName() {
		return tableName;
	}

	public void setTableName(String tableName) {
		this.tableName = tableName;
	}

	public Long getAttributeId() {
		return attributeId;
	}

	public void setAttributeId(Long attributeId) {
		this.attributeId = attributeId;
	}

	public String getAttributeName() {
		return attributeName;
	}

	public void setAttributeName(String attributeName) {
		this.attributeName = attributeName;
	}

	public String getAttributeCode() {
		return attributeCode;
	}

	public void setAttributeCode(String attributeCode) {
		this.attributeCode = attributeCode;
	}

	public String getProjectDisplayName() {
		return projectDisplayName;
	}

	public void setProjectDisplayName(String projectDisplayName) {
		this.projectDisplayName = projectDisplayName;
	}

	public String getEntityDisplayName() {
		return entityDisplayName;
	}

	public void setEntityDisplayName(String entityDisplayName) {
		this.entityDisplayName = entityDisplayName;
	}
	
}

==> ejc-metadata-api-3.0.0-20230104.084935-250-sources.jar: com/ejianc/foundation/metadata/vo/MdQuoteVO.java <==
package com.ejianc.foundation.metadata.vo;

import java.util.List;

/**
 * 查询引用关系返回VO
 */
public class MdQuoteVO {

	private static final long serialVersionUID = 1L;

	private String projectName;		//工程名称
	
	private String projectDisplayName;		//工程名称
	
	private Long projectId;			//工程id
	
	private String databaseName; //工程对应数据库名称

	private String entityName; // 实体名称

	private String entityDisplayName; // 实体名称

	private String entityFullName; // 实体全名

	private String tableName; // 表名称
	
	private Long attributeId;	//引用字段id
	
	private String attributeName;	//引用字段名称

	private String attributeCode;	//引用字段(数据库表中的名称)

	private List<MdRelationQuoteVO> relationQuoteList;

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getDatabaseName() {
		return databaseName;
	}

	public void setDatabaseName(String databaseName) {
		this.databaseName = databaseName;
	}

	public String getEntityName() {
		return entityName;
	}

	public void setEntityName(String entityName) {
		this.entityName = entityName;
	}

	public String getEntityFullName() {
		return entityFullName;
	}

	public void setEntityFullName(String entityFullName) {
		this.entityFullName = entityFullName;
	}

	public String getTableName() {
		return tableName;
	}

	public void setTableName(String tableName) {
		this.tableName = tableName;
	}

	public Long getAttributeId() {
		return attributeId;
	}

	public void setAttributeId(Long attributeId) {
		this.attributeId = attributeId;
	}

	public String getAttributeName() {
		return attributeName;
	}

	public void setAttributeName(String attributeName) {
		this.attributeName = attributeName;
	}

	public String getAttributeCode() {
		return attributeCode;
	}

	public void setAttributeCode(String attributeCode) {
		this.attributeCode = attributeCode;
	}

	public String getProjectDisplayName() {
		return projectDisplayName;
	}

	public void setProjectDisplayName(String projectDisplayName) {
		this.projectDisplayName = projectDisplayName;
	}

	public String getEntityDisplayName() {
		return entityDisplayName;
	}

	public void setEntityDisplayName(String entityDisplayName) {
		this.entityDisplayName = entityDisplayName;
	}

	public List<MdRelationQuoteVO> getRelationQuoteList() {
		return relationQuoteList;
	}

	public void setRelationQuoteList(List<MdRelationQuoteVO> relationQuoteList) {
		this.relationQuoteList = relationQuoteList;
	}
}
